summaryrefslogtreecommitdiffstats
path: root/src/com/itmill
diff options
context:
space:
mode:
authorJani Laakso <jani.laakso@itmill.com>2007-04-26 17:03:48 +0000
committerJani Laakso <jani.laakso@itmill.com>2007-04-26 17:03:48 +0000
commit5f2ce2944b1460367109dcbc453290409b450527 (patch)
treeb50915348373417658d4d041999d5809d4713366 /src/com/itmill
parent897cd419bbbebfed11ee5f80ba7f5c0455bed09c (diff)
downloadvaadin-framework-5f2ce2944b1460367109dcbc453290409b450527.tar.gz
vaadin-framework-5f2ce2944b1460367109dcbc453290409b450527.zip
KeyboardShortcut considered as beta.
svn changeset:1361/svn branch:trunk
Diffstat (limited to 'src/com/itmill')
-rw-r--r--src/com/itmill/toolkit/demo/KeyboardShortcut.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/com/itmill/toolkit/demo/KeyboardShortcut.java b/src/com/itmill/toolkit/demo/KeyboardShortcut.java
index 8dc0982641..ac5f2e69a0 100644
--- a/src/com/itmill/toolkit/demo/KeyboardShortcut.java
+++ b/src/com/itmill/toolkit/demo/KeyboardShortcut.java
@@ -6,7 +6,7 @@ import com.itmill.toolkit.event.Action.Handler;
import com.itmill.toolkit.ui.*;
/**
* Note: This feature is under development and is considered as alpha
*
* @author IT Mill Ltd.
*
@@ -48,7 +48,7 @@ public class KeyboardShortcut extends com.itmill.toolkit.Application implements
main
.addComponent(new Label(
"<h3>Test application for shortcut actions</h3>"
- + "<b>Note: This feature is under development and is considered as alpha.</b><br />"
+ + "<b>Note: This feature is under development and is considered as beta.</b><br />"
+ "<b>Note:</b> if events do not work, <b>set focus to Textfield first.</b>",
Label.CONTENT_XHTML));
main
@@ -6,7 +6,7 @@ import com.itmill.toolkit.event.Action.Handler;
import com.itmill.toolkit.ui.*;
/**
- * Note: This feature is under development and is considered as alpha
+ * Note: This feature is under development and is considered as beta
*
* @author IT Mill Ltd.